import request from '@/utils/request'

// 工程项目-列表
export function getProjectList(query) {
  return request({
    url: '/material/bm_project/list',
    method: 'get',
    params: query
  })
}
//工程项目--新增
export function addProject(data) {
  return request({
    url: '/material/bm_project',
    method: 'post',
    data: data
  })
}

// 工程项目--修改
export function updateProject(data) {
  return request({
    url: '/material/bm_project',
    method: 'put',
    data: data
  })
}
// //工程项目--删除
export function delProject(proId) {
  return request({
    url: '/material/bm_project/' + proId,
    method: 'delete'
  })
}

// 工程项目
export function getProjectUserList(query) {
  return request({
    url: '/material/bm_unit_person/getDeptUserTree',
    method: 'get',
    params: {
      query,  
      isTree: 1 // 添加 isTree 参数
    }
  });
}
// 标段工程-列表
export function ProjectLotList(query) {
  return request({
    url: '/material/base/bmProjectLot/projectLotAll',
    method: 'get',
    params: query
  })
}
//标段工程--新增
export function addProjectLot(data) {
  return request({
    url: '/material/base/bmProjectLot',
    method: 'post',
    data: data
  })
}

// 标段工程--修改
export function updateProjectLot(data) {
  return request({
    url: '/material/base/bmProjectLot',
    method: 'put',
    data: data
  })
}
//标段工程--删除
export function delProjectLot(lotId) {
  return request({
    url: '/material/base/bmProjectLot/' + lotId,
    method: 'delete'
  })
}
//工程项目下拉数据
export function getProjectSelect(data) {
  return request({
    url: '/material/base/bmProjectInfo/getProjectLot',
    method: 'post',
    data: data
  })
}


// 往来单位-列表
export function unitInfoAll(query) {
  return request({
    url: '/material/bm_unit/list',
    method: 'get',
    params: query
  })
}
//往来单位--新增
export function addUnit(data) {
  return request({
    url: '/material/bm_unit',
    method: 'post',
    data: data
  })
}

// 往来单位--修改
export function updateUnit(data) {
  return request({
    url: '/material/bm_unit',
    method: 'put',
    data: data
  })
}
// 往来单位--删除
export function delUnit(unitId) {
  return request({
    url: '/material/bm_unit/' + unitId,
    method: 'delete'
  })
}


// 往来单位-人员配置-左侧人员
export function getUserList(query) {
  return request({
    url: '/material/bm_unit_person/getDeptUserTree',
    method: 'get',
    params: query
  })
}

// 往来单位-人员配置-右侧单位
export function getTypeList(query) {
  return request({
    url: '/material/bm_unit/list',
    method: 'get',
    params: query
  })
}

// 往来单位-人员配置-保存按钮
export function unitPersonAll(query) {
  return request({
    url: '/material/bm_unit_person/bind',
    method: 'post',
    data: query
  })
}

// 往来单位-人员配置-解绑
export function delUnitPerson(unitId) {
  return request({
    url: '/material/bm_unit_person/' + unitId,
    method: 'delete'
  })
}


// 字典表数据库
// 单位类型-列表
export function unitTypeList(query) {
  return request({
    url: '/material/bm_unit_type/list',
    method: 'get',
    params: query
  })
}
// 单位类型-列表-下拉
export function unitTypeListAll(query) {
  return request({
    url: '/material/bm_unit_type/list',
    method: 'get',
    params: query
  })
}
// 标签编号-列表
export function getMaMachineLabelApi(query) {
  return request({
    url: '/material/base/maMachineLabel/list',
    method: 'get',
    params: query
  })
}
//单位类型--新增
export function addMaMachineLabelApi(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'post',
    data: data
  })
}
// 单位类型-详情
export function unitTypeDetail(typeId) {
  return request({
    url: `/material/bm_unit_type/${typeId}`,
    method: 'get',
  })
}
//单位类型--新增
export function addUnitType(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'post',
    data: data
  })
}

// 单位类型--修改
export function updateUnitType(data) {
  return request({
    url: '/material/bm_unit_type',
    method: 'put',
    data: data
  })
}

export function statusUnitType(data) {
  return request({
    url: '/material/base/dic/status',
    method: 'put',
    params: data
  })
}

//单位类型--删除
export function delUnitType(typeIds) {
  return request({
    url: '/material/bm_unit_type/' + typeIds,
    method: 'delete'
  })
}



// 资产属性管理-列表
export function propInfoList(query) {
  return request({
    url: '/material/bm_asset_attributes/list',
    method: 'get',
    params: query
  })
}
//资产属性管理--新增
export function addPropInfo(data) {
  return request({
    url: '/material/bm_asset_attributes',
    method: 'post',
    data: data
  })
}

// 资产属性管理--修改
export function updatePropInfo(data) {
  return request({
    url: '/material/bm_asset_attributes',
    method: 'put',
    data: data
  })
}
//资产属性管理--删除
export function delPropInfo(id) {
  return request({
    url: `/material/bm_asset_attributes/${id}`,
    method: 'delete'
  })
}

// 资产属性管理-详情
export function PropDetail(id) {
  return request({
    url: `/material/bm_asset_attributes/${id}`,
    method: 'get',
  })
}



// // 资产属性配置-左侧人员
// export function getProLists(query) {
//   return request({
//     url: '/material/base/maPropInfo/lists',
//     method: 'get',
//     params: query
//   })
// }

// // 资产属性配置-右侧list
// export function getMaTypeList(query) {
//   return request({
//     url: '/material/base/maPropInfo/getMaTypeList',
//     method: 'get',
//     params: query
//   })
// }

// // 资产属性配置-保存按钮
// export function savePropInfo(query) {
//   return request({
//     url: '/material/base/maPropInfo/save',
//     method: 'post',
//     data: query
//   })
// }

// // 资产属性配置-解绑
// export function UnbindPropInfo(unitId) {
//   return request({
//     url: '/material/base/maPropSet/' + unitId,
//     method: 'delete'
//   })
// }


// 获取设备信息-qrCode
export function getMachineByQrCode(query) {
  return request({
    url: '/material/base/machine/getMachineByQrCode',
    method: 'get',
    params: query
  })
}




